==> zio-aws-apigatewayv2_2.12-5.19.33.1-sources.jar: zio/aws/apigatewayv2/model/DeleteDeploymentRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDeploymentRequest(
    apiId: __string,
    deploymentId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest = {
    import DeleteDeploymentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .deploymentId(deploymentId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteDeploymentRequest.wrap(buildAwsValue())
}
object DeleteDeploymentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteDeploymentRequest =
      zio.aws.apigatewayv2.model.DeleteDeploymentRequest(apiId, deploymentId)
    def apiId: __string
    def deploymentId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getDeploymentId: ZIO[Any, Nothing, __string] = ZIO.succeed(deploymentId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ) extends zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val deploymentId: __string = impl.deploymentId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ): zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.13-5.17.104.7-sources.jar: zio/aws/apigatewayv2/model/DeleteDeploymentRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteDeploymentRequest(
    apiId: __string,
    deploymentId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest = {
    import DeleteDeploymentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .deploymentId(__string.unwrap(deploymentId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteDeploymentRequest.wrap(buildAwsValue())
}
object DeleteDeploymentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteDeploymentRequest =
      zio.aws.apigatewayv2.model.DeleteDeploymentRequest(apiId, deploymentId)
    def apiId: __string
    def deploymentId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getDeploymentId: ZIO[Any, Nothing, __string] = ZIO.succeed(deploymentId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ) extends zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val deploymentId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.deploymentId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteDeploymentRequest
  ): zio.aws.apigatewayv2.model.DeleteDeploymentRequest.ReadOnly = new Wrapper(
    impl
  )
}
